import numpy as np
from shogun import AccuracyMeasure
from shogun import BinaryLabels
from shogun import CSVFile
from shogun import CombinedFeatures
from shogun import CombinedKernel
from shogun import CrossValidation
from shogun import CrossValidationResult
from shogun import GaussianKernel
from shogun import LibSVM
from shogun import MKLClassification
from shogun import ParameterObserverCV
from shogun import RealFeatures
from shogun import StratifiedCrossValidationSplitting

f_feats = CSVFile("../../data/fm_train_real.dat")
f_labels = CSVFile("../../data/label_train_twoclass.dat")

#![create_features]
features = RealFeatures(f_feats)
combined_features = CombinedFeatures()
combined_features.append_feature_obj(features)
combined_features.append_feature_obj(features)
combined_features.append_feature_obj(features)
labels = BinaryLabels(f_labels)
#![create_features]

#![create_kernels]
kernel = CombinedKernel()
k_1 = GaussianKernel(10, 0.1)
k_2 = GaussianKernel(10, 1)
k_3 = GaussianKernel(10, 2)
kernel.append_kernel(k_1)
kernel.append_kernel(k_2)
kernel.append_kernel(k_3)
#![create_kernels]

#![create_classifier]
libsvm = LibSVM()
svm = MKLClassification(libsvm)
svm.set_interleaved_optimization_enabled(False)
svm.set_kernel(kernel)
#![create_classifier]

#![create_cross_validation]
splitting_strategy = StratifiedCrossValidationSplitting(labels, 5)
evaluation_criterium = AccuracyMeasure()
cross = CrossValidation(svm, combined_features, labels, splitting_strategy, evaluation_criterium)
cross.set_autolock(False)
cross.set_num_runs(2)
#![create_cross_validation]

#![create_observer]
mkl_obs = ParameterObserverCV(True)
cross.subscribe_to_parameters(mkl_obs)
#[!create_observer]

#![evaluate_and_get_result]
result = CrossValidationResult()
result = CrossValidationResult.obtain_from_generic(cross.evaluate())
#![evaluate_and_get_result]

#![get_results]
mean = result.get_mean()
stddev = result.get_std_dev()
#![get_results]

#![get_fold_machine]
obs = mkl_obs.get_observation(0)
fold = obs.get_fold(0)
machine = MKLClassification.obtain_from_generic(fold.get_trained_machine())
#![get_fold_machine]

#![get_weights]
k = CombinedKernel.obtain_from_generic(machine.get_kernel())
w = k.get_subkernel_weights()
#![get_weights]
