import numpy as np
from shogun import CSVFile
from shogun import GaussianKernel
from shogun import KRRNystrom
from shogun import MeanSquaredError
from shogun import RealFeatures
from shogun import RegressionLabels

f_feats_train = CSVFile("../../data/regression_1d_sinc_features_train.dat")
f_feats_test = CSVFile("../../data/regression_1d_sinc_features_test.dat")
f_labels_train = CSVFile("../../data/regression_1d_sinc_labels_train.dat")
f_labels_test = CSVFile("../../data/regression_1d_sinc_labels_test.dat")

#![create_features]
features_train = RealFeatures(f_feats_train)
features_test = RealFeatures(f_feats_test)
labels_train = RegressionLabels(f_labels_train)
labels_test = RegressionLabels(f_labels_test)
#![create_features]

#![create_appropriate_kernel]
width = 1.0
kernel = GaussianKernel(features_train, features_train, width)
#![create_appropriate_kernel]

#![create_instance]
tau = 0.001
m = 100
nystrom = KRRNystrom(tau, m, kernel, labels_train)
#![create_instance]

#![train_and_apply]
nystrom.train()
labels_predict = nystrom.apply_regression(features_test)
#![train_and_apply]

#![extract_alpha]
nystrom.get_alphas()
#![extract_alpha]

#![evaluate_error]
eval = MeanSquaredError()
eval.evaluate(labels_predict, labels_test)
#![evaluate_error]

# integration testing variables
output = labels_test.get_labels()
