import numpy as np
from shogun import CSVFile
from shogun import GaussianKernel
from shogun import LIBSVR_EPSILON_SVR
from shogun import LibSVR
from shogun import MeanSquaredError
from shogun import RealFeatures
from shogun import RegressionLabels

f_feats_train = CSVFile("../../data/regression_1d_sinc_features_train.dat")
f_feats_test = CSVFile("../../data/regression_1d_sinc_features_test.dat")
f_labels_train = CSVFile("../../data/regression_1d_sinc_labels_train.dat")
f_labels_test = CSVFile("../../data/regression_1d_sinc_labels_test.dat")

#![create_features]
features_train = RealFeatures(f_feats_train)
features_test = RealFeatures(f_feats_test)
labels_train = RegressionLabels(f_labels_train)
labels_test = RegressionLabels(f_labels_test)
#![create_features]

#![create_appropriate_kernel]
width = 1.0
kernel = GaussianKernel(width)
#![create_appropriate_kernel]

#![create_instance]
svm_c = 1.0
svr_param = 0.1
svr = LibSVR(svm_c, svr_param, kernel, labels_train, LIBSVR_EPSILON_SVR)
#![create_instance]

#![train_and_apply]
svr.train(features_train)
labels_predict = svr.apply_regression(features_test)
#![train_and_apply]

#![extract_alpha]
alpha = svr.get_alphas()
#![extract_alpha]

#![evaluate_error]
eval = MeanSquaredError()
mse = eval.evaluate(labels_predict, labels_test)
#![evaluate_error]

# integration testing variables
output = labels_test.get_labels()
